import typing as t

from atproto_client.client.base import ClientBase
from atproto_client.namespaces import sync_ns

# TODO(MarshalX): This file should be autogenerated!


class ClientRaw(ClientBase):
    """Group all root namespaces."""

    com: 'sync_ns.ComNamespace'
    app: 'sync_ns.AppNamespace'
    tools: 'sync_ns.ToolsNamespace'
    chat: 'sync_ns.ChatNamespace'

    def __init__(self, *args: t.Any, **kwargs: t.Any) -> None:
        super().__init__(*args, **kwargs)

        self.com = sync_ns.ComNamespace(self)
        self.app = sync_ns.AppNamespace(self)
        self.tools = sync_ns.ToolsNamespace(self)
        self.chat = sync_ns.ChatNamespace(self)
